@@ -15,7 +15,7 @@ function(x, which.ones=NULL)
     x <- as.zoo(x)
     x.index <- index(x)
     xIsRegular <- is.regular(x, strict=TRUE)
-    if(xIsRegular){
+    if(xIsRegular && frequency(x)>1 ){
       xIndexObs <- floor(as.numeric(x.index))
       xCycle <- as.numeric(cycle(x))
       xIndexAsChar <- paste(xIndexObs, "(", xCycle, ")", sep="")
